@@ -18,17 +18,6 @@
  */
 package org.apache.parquet.schema;
 
-import org.apache.parquet.Preconditions;
-import org.apache.yetus.audience.InterfaceAudience;
-
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Objects;
-import java.util.Optional;
-import java.util.Set;
-import java.util.function.Supplier;
-
 import static java.util.Arrays.asList;
 import static java.util.Optional.empty;
 import static org.apache.parquet.schema.ColumnOrder.ColumnOrderName.TYPE_DEFINED_ORDER;
@@ -44,6 +33,15 @@ import static org.apache.parquet.schema.PrimitiveStringifier.TIME_NANOS_UTC_STRI
 import static org.apache.parquet.schema.PrimitiveStringifier.TIME_STRINGIFIER;
 import static org.apache.parquet.schema.PrimitiveStringifier.TIME_UTC_STRINGIFIER;
 
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.Set;
+import java.util.function.Supplier;
+import org.apache.parquet.Preconditions;
+
 public abstract class LogicalTypeAnnotation {
   enum LogicalTypeToken {
     MAP {
@@ -82,7 +80,7 @@ public abstract class LogicalTypeAnnotation {
         if (params.size() != 2) {
           throw new RuntimeException("Expecting 2 parameters for decimal logical type, got " + params.size());
         }
-        return decimalType(Integer.valueOf(params.get(1)), Integer.valueOf(params.get(0)));
+        return decimalType(Integer.parseInt(params.get(1)), Integer.parseInt(params.get(0)));
       }
     },
     DATE {
@@ -104,7 +102,8 @@ public abstract class LogicalTypeAnnotation {
       @Override
       protected LogicalTypeAnnotation fromString(List<String> params) {
         if (params.size() != 2) {
-          throw new RuntimeException("Expecting 2 parameters for timestamp logical type, got " + params.size());
+          throw new RuntimeException(
+              "Expecting 2 parameters for timestamp logical type, got " + params.size());
         }
         return timestampType(Boolean.parseBoolean(params.get(1)), TimeUnit.valueOf(params.get(0)));
       }
@@ -115,7 +114,7 @@ public abstract class LogicalTypeAnnotation {
         if (params.size() != 2) {
           throw new RuntimeException("Expecting 2 parameters for integer logical type, got " + params.size());
         }
-        return intType(Integer.valueOf(params.get(0)), Boolean.parseBoolean(params.get(1)));
+        return intType(Integer.parseInt(params.get(0)), Boolean.parseBoolean(params.get(1)));
       }
     },
     JSON {
@@ -141,6 +140,12 @@ public abstract class LogicalTypeAnnotation {
       protected LogicalTypeAnnotation fromString(List<String> params) {
         return IntervalLogicalTypeAnnotation.getInstance();
       }
+    },
+    FLOAT16 {
+      @Override
+      protected LogicalTypeAnnotation fromString(List<String> params) {
+        return float16Type();
+      }
     };
 
     protected abstract LogicalTypeAnnotation fromString(List<String> params);
@@ -149,10 +154,13 @@ public abstract class LogicalTypeAnnotation {
   /**
    * Convert this logical type to old logical type representation in parquet-mr (if there's any).
    * Those logical type implementations, which don't have a corresponding mapping should return null.
+   * <p>
+   * API should be considered private
    *
    * @return the OriginalType representation of the new logical type, or null if there's none
+   * @deprecated Please use the LogicalTypeAnnotation itself
    */
-  @InterfaceAudience.Private
+  @Deprecated
   public abstract OriginalType toOriginalType();
 
   /**
@@ -174,10 +182,7 @@ public abstract class LogicalTypeAnnotation {
 
   @Override
   public String toString() {
-    StringBuilder sb = new StringBuilder();
-    sb.append(getType());
-    sb.append(typeParametersAsString());
-    return sb.toString();
+    return getType() + typeParametersAsString();
   }
 
   PrimitiveStringifier valueStringifier(PrimitiveType primitiveType) {
@@ -186,8 +191,9 @@ public abstract class LogicalTypeAnnotation {
 
   /**
    * Helper method to convert the old representation of logical types (OriginalType) to new logical type.
+   * <p>
+   * API should be considered private
    */
-  @InterfaceAudience.Private
   public static LogicalTypeAnnotation fromOriginalType(OriginalType originalType, DecimalMetadata decimalMetadata) {
     if (originalType == null) {
       return null;
@@ -240,7 +246,8 @@ public abstract class LogicalTypeAnnotation {
       case MAP_KEY_VALUE:
         return MapKeyValueTypeAnnotation.getInstance();
       default:
-        throw new RuntimeException("Can't convert original type to logical type, unknown original type " + originalType);
+        throw new RuntimeException(
+            "Can't convert original type to logical type, unknown original type " + originalType);
     }
   }
 
@@ -276,14 +283,23 @@ public abstract class LogicalTypeAnnotation {
     return new TimestampLogicalTypeAnnotation(isAdjustedToUTC, unit);
   }
 
+  public static IntLogicalTypeAnnotation intType(final int bitWidth) {
+    return new IntLogicalTypeAnnotation(bitWidth, true);
+  }
+
   public static IntLogicalTypeAnnotation intType(final int bitWidth, final boolean isSigned) {
     Preconditions.checkArgument(
-      bitWidth == 8 || bitWidth == 16 || bitWidth == 32 || bitWidth == 64,
-      "Invalid bit width for integer logical type, %s is not allowed, " +
-        "valid bit width values: 8, 16, 32, 64", bitWidth);
+        bitWidth == 8 || bitWidth == 16 || bitWidth == 32 || bitWidth == 64,
+        "Invalid bit width for integer logical type, %s is not allowed, "
+            + "valid bit width values: 8, 16, 32, 64",
+        bitWidth);
     return new IntLogicalTypeAnnotation(bitWidth, isSigned);
   }
 
+  public static IntervalLogicalTypeAnnotation intervalType() {
+    return new IntervalLogicalTypeAnnotation();
+  }
+
   public static JsonLogicalTypeAnnotation jsonType() {
     return JsonLogicalTypeAnnotation.INSTANCE;
   }
@@ -296,14 +312,23 @@ public abstract class LogicalTypeAnnotation {
     return UUIDLogicalTypeAnnotation.INSTANCE;
   }
 
+  public static Float16LogicalTypeAnnotation float16Type() {
+    return Float16LogicalTypeAnnotation.INSTANCE;
+  }
+
   public static class StringLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final StringLogicalTypeAnnotation INSTANCE = new StringLogicalTypeAnnotation();
 
-    private StringLogicalTypeAnnotation() {
-    }
+    private StringLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.UTF8;
     }
@@ -338,11 +363,16 @@ public abstract class LogicalTypeAnnotation {
   public static class MapLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final MapLogicalTypeAnnotation INSTANCE = new MapLogicalTypeAnnotation();
 
-    private MapLogicalTypeAnnotation() {
-    }
+    private MapLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.MAP;
     }
@@ -372,11 +402,16 @@ public abstract class LogicalTypeAnnotation {
   public static class ListLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final ListLogicalTypeAnnotation INSTANCE = new ListLogicalTypeAnnotation();
 
-    private ListLogicalTypeAnnotation() {
-    }
+    private ListLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.LIST;
     }
@@ -406,11 +441,16 @@ public abstract class LogicalTypeAnnotation {
   public static class EnumLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final EnumLogicalTypeAnnotation INSTANCE = new EnumLogicalTypeAnnotation();
 
-    private EnumLogicalTypeAnnotation() {
-    }
+    private EnumLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.ENUM;
     }
@@ -461,8 +501,14 @@ public abstract class LogicalTypeAnnotation {
       return scale;
     }
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.DECIMAL;
     }
@@ -479,13 +525,7 @@ public abstract class LogicalTypeAnnotation {
 
     @Override
     protected String typeParametersAsString() {
-      StringBuilder sb = new StringBuilder();
-      sb.append("(");
-      sb.append(precision);
-      sb.append(",");
-      sb.append(scale);
-      sb.append(")");
-      return sb.toString();
+      return "(" + precision + "," + scale + ")";
     }
 
     @Override
@@ -511,11 +551,16 @@ public abstract class LogicalTypeAnnotation {
   public static class DateLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final DateLogicalTypeAnnotation INSTANCE = new DateLogicalTypeAnnotation();
 
-    private DateLogicalTypeAnnotation() {
-    }
+    private DateLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.DATE;
     }
@@ -562,8 +607,14 @@ public abstract class LogicalTypeAnnotation {
       this.unit = unit;
     }
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       switch (unit) {
         case MILLIS:
@@ -587,13 +638,7 @@ public abstract class LogicalTypeAnnotation {
 
     @Override
     protected String typeParametersAsString() {
-      StringBuilder sb = new StringBuilder();
-      sb.append("(");
-      sb.append(unit);
-      sb.append(",");
-      sb.append(isAdjustedToUTC);
-      sb.append(")");
-      return sb.toString();
+      return "(" + unit + "," + isAdjustedToUTC + ")";
     }
 
     public TimeUnit getUnit() {
@@ -641,8 +686,14 @@ public abstract class LogicalTypeAnnotation {
       this.unit = unit;
     }
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       switch (unit) {
         case MILLIS:
@@ -666,13 +717,7 @@ public abstract class LogicalTypeAnnotation {
 
     @Override
     protected String typeParametersAsString() {
-      StringBuilder sb = new StringBuilder();
-      sb.append("(");
-      sb.append(unit);
-      sb.append(",");
-      sb.append(isAdjustedToUTC);
-      sb.append(")");
-      return sb.toString();
+      return "(" + unit + "," + isAdjustedToUTC + ")";
     }
 
     public TimeUnit getUnit() {
@@ -713,8 +758,8 @@ public abstract class LogicalTypeAnnotation {
   }
 
   public static class IntLogicalTypeAnnotation extends LogicalTypeAnnotation {
-    private static final Set<Integer> VALID_BIT_WIDTH = Collections.unmodifiableSet(
-      new HashSet<>(asList(8, 16, 32, 64)));
+    private static final Set<Integer> VALID_BIT_WIDTH =
+        Collections.unmodifiableSet(new HashSet<>(asList(8, 16, 32, 64)));
 
     private final int bitWidth;
     private final boolean isSigned;
@@ -727,8 +772,14 @@ public abstract class LogicalTypeAnnotation {
       this.isSigned = isSigned;
     }
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       switch (bitWidth) {
         case 8:
@@ -756,13 +807,7 @@ public abstract class LogicalTypeAnnotation {
 
     @Override
     protected String typeParametersAsString() {
-      StringBuilder sb = new StringBuilder();
-      sb.append("(");
-      sb.append(bitWidth);
-      sb.append(",");
-      sb.append(isSigned);
-      sb.append(")");
-      return sb.toString();
+      return "(" + bitWidth + "," + isSigned + ")";
     }
 
     public int getBitWidth() {
@@ -796,11 +841,16 @@ public abstract class LogicalTypeAnnotation {
   public static class JsonLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final JsonLogicalTypeAnnotation INSTANCE = new JsonLogicalTypeAnnotation();
 
-    private JsonLogicalTypeAnnotation() {
-    }
+    private JsonLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.JSON;
     }
@@ -835,11 +885,16 @@ public abstract class LogicalTypeAnnotation {
   public static class BsonLogicalTypeAnnotation extends LogicalTypeAnnotation {
     private static final BsonLogicalTypeAnnotation INSTANCE = new BsonLogicalTypeAnnotation();
 
-    private BsonLogicalTypeAnnotation() {
-    }
+    private BsonLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.BSON;
     }
@@ -875,11 +930,16 @@ public abstract class LogicalTypeAnnotation {
     private static final UUIDLogicalTypeAnnotation INSTANCE = new UUIDLogicalTypeAnnotation();
     public static final int BYTES = 16;
 
-    private UUIDLogicalTypeAnnotation() {
-    }
+    private UUIDLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       // No OriginalType for UUID
       return null;
@@ -901,6 +961,34 @@ public abstract class LogicalTypeAnnotation {
     }
   }
 
+  public static class Float16LogicalTypeAnnotation extends LogicalTypeAnnotation {
+    private static final Float16LogicalTypeAnnotation INSTANCE = new Float16LogicalTypeAnnotation();
+    public static final int BYTES = 2;
+
+    private Float16LogicalTypeAnnotation() {}
+
+    @Override
+    public OriginalType toOriginalType() {
+      // No OriginalType for Float16
+      return null;
+    }
+
+    @Override
+    public <T> Optional<T> accept(LogicalTypeAnnotationVisitor<T> logicalTypeAnnotationVisitor) {
+      return logicalTypeAnnotationVisitor.visit(this);
+    }
+
+    @Override
+    LogicalTypeToken getType() {
+      return LogicalTypeToken.FLOAT16;
+    }
+
+    @Override
+    PrimitiveStringifier valueStringifier(PrimitiveType primitiveType) {
+      return PrimitiveStringifier.FLOAT16_STRINGIFIER;
+    }
+  }
+
   // This logical type annotation is implemented to support backward compatibility with ConvertedType.
   // The new logical type representation in parquet-format doesn't have any interval type,
   // thus this annotation is mapped to UNKNOWN.
@@ -911,11 +999,16 @@ public abstract class LogicalTypeAnnotation {
       return INSTANCE;
     }
 
-    private IntervalLogicalTypeAnnotation() {
-    }
+    private IntervalLogicalTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.INTERVAL;
     }
@@ -962,11 +1055,16 @@ public abstract class LogicalTypeAnnotation {
       return INSTANCE;
     }
 
-    private MapKeyValueTypeAnnotation() {
-    }
+    private MapKeyValueTypeAnnotation() {}
 
+    /**
+     * API Should be considered private
+     *
+     * @return the original type
+     * @deprecated Please use the LogicalTypeAnnotation itself
+     */
     @Override
-    @InterfaceAudience.Private
+    @Deprecated
     public OriginalType toOriginalType() {
       return OriginalType.MAP_KEY_VALUE;
     }
@@ -998,7 +1096,7 @@ public abstract class LogicalTypeAnnotation {
    * The default implementation for each logical type specific visitor method is empty.
    * <p>
    * Example usage: logicalTypeAnnotation.accept(new LogicalTypeAnnotationVisitor() { ... });
-   *
+   * <p>
    * Every visit method returns {@link Optional#empty()} by default.
    * It means that for the given logical type no specific action is needed.
    * Client code can use {@link Optional#orElse(Object)} to return a default value for unhandled types,
@@ -1060,5 +1158,9 @@ public abstract class LogicalTypeAnnotation {
     default Optional<T> visit(MapKeyValueTypeAnnotation mapKeyValueLogicalType) {
       return empty();
     }
+
+    default Optional<T> visit(Float16LogicalTypeAnnotation float16LogicalType) {
+      return empty();
+    }
   }
 }
