@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,24 +18,6 @@
  */
 package org.apache.parquet.io;
 
-import java.util.ArrayList;
-import java.util.List;
-
-import org.apache.parquet.column.ParquetProperties;
-import org.apache.parquet.io.api.RecordConsumer;
-import org.junit.Test;
-
-import org.apache.parquet.column.impl.ColumnWriteStoreV1;
-import org.apache.parquet.column.page.mem.MemPageStore;
-import org.apache.parquet.example.data.Group;
-import org.apache.parquet.example.data.GroupWriter;
-import org.apache.parquet.example.data.simple.convert.GroupRecordConverter;
-import org.apache.parquet.filter.ColumnPredicates.LongPredicateFunction;
-import org.apache.parquet.filter.ColumnPredicates.PredicateFunction;
-import org.apache.parquet.filter2.compat.FilterCompat;
-import org.apache.parquet.io.api.RecordMaterializer;
-
-import static org.junit.Assert.assertEquals;
 import static org.apache.parquet.example.Paper.r1;
 import static org.apache.parquet.example.Paper.r2;
 import static org.apache.parquet.example.Paper.schema;
@@ -47,6 +29,22 @@ import static org.apache.parquet.filter.ColumnRecordFilter.column;
 import static org.apache.parquet.filter.NotRecordFilter.not;
 import static org.apache.parquet.filter.OrRecordFilter.or;
 import static org.apache.parquet.filter.PagedRecordFilter.page;
+import static org.junit.Assert.assertEquals;
+
+import java.util.ArrayList;
+import java.util.List;
+import org.apache.parquet.column.ParquetProperties;
+import org.apache.parquet.column.impl.ColumnWriteStoreV1;
+import org.apache.parquet.column.page.mem.MemPageStore;
+import org.apache.parquet.example.data.Group;
+import org.apache.parquet.example.data.GroupWriter;
+import org.apache.parquet.example.data.simple.convert.GroupRecordConverter;
+import org.apache.parquet.filter.ColumnPredicates.LongPredicateFunction;
+import org.apache.parquet.filter.ColumnPredicates.PredicateFunction;
+import org.apache.parquet.filter2.compat.FilterCompat;
+import org.apache.parquet.io.api.RecordConsumer;
+import org.apache.parquet.io.api.RecordMaterializer;
+import org.junit.Test;
 
 public class TestFiltered {
 
@@ -78,162 +76,157 @@ public class TestFiltered {
   private void readOne(RecordReader<Group> reader, String message, Group expected) {
     List<Group> result = readAll(reader);
     assertEquals(message + ": " + result, 1, result.size());
-    assertEquals("filtering did not return the correct record", expected.toString(), result.get(0).toString());
+    assertEquals(
+        "filtering did not return the correct record",
+        expected.toString(),
+        result.get(0).toString());
   }
 
   @Test
   public void testFilterOnInteger() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 1);
 
     // Get first record
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter, FilterCompat.get(column("DocId", equalTo(10l))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("DocId", equalTo(10l))));
 
     readOne(recordReader, "r2 filtered out", r1);
 
     // Get second record
-    recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("DocId", equalTo(20l))));
+    recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("DocId", equalTo(20l))));
 
     readOne(recordReader, "r1 filtered out", r2);
-
   }
 
   @Test
   public void testApplyFunctionFilterOnLong() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 1);
 
     // Get first record
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("DocId", equalTo(10l))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("DocId", equalTo(10l))));
 
     readOne(recordReader, "r2 filtered out", r1);
 
     // Get second record
-    recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("DocId", applyFunctionToLong(new LongGreaterThan15Predicate()))));
+    recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore,
+        recordConverter,
+        FilterCompat.get(column("DocId", applyFunctionToLong(new LongGreaterThan15Predicate()))));
 
     readOne(recordReader, "r1 filtered out", r2);
   }
 
   @Test
   public void testFilterOnString() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 1);
 
     // First try matching against the A url in record 1
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("Name.Url", equalTo("http://A"))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("Name.Url", equalTo("http://A"))));
 
     readOne(recordReader, "r2 filtered out", r1);
 
     // Second try matching against the B url in record 1 - it should fail as we only match
     // against the first instance of a
-    recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("Name.Url", equalTo("http://B"))));
+    recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("Name.Url", equalTo("http://B"))));
 
     List<Group> all = readAll(recordReader);
-    assertEquals("There should be no matching records: " + all , 0, all.size());
+    assertEquals("There should be no matching records: " + all, 0, all.size());
 
     // Finally try matching against the C url in record 2
-    recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("Name.Url", equalTo("http://C"))));
+    recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("Name.Url", equalTo("http://C"))));
 
     readOne(recordReader, "r1 filtered out", r2);
-
   }
 
   @Test
   public void testApplyFunctionFilterOnString() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 1);
 
     // First try matching against the A url in record 1
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("Name.Url", applyFunctionToString(new StringEndsWithAPredicate()))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore,
+        recordConverter,
+        FilterCompat.get(column("Name.Url", applyFunctionToString(new StringEndsWithAPredicate()))));
 
     readOne(recordReader, "r2 filtered out", r1);
 
     // Second try matching against the B url in record 1 - it should fail as we only match
     // against the first instance of a
-    recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("Name.Url", equalTo("http://B"))));
+    recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("Name.Url", equalTo("http://B"))));
 
     List<Group> all = readAll(recordReader);
-    assertEquals("There should be no matching records: " + all , 0, all.size());
+    assertEquals("There should be no matching records: " + all, 0, all.size());
 
     // Finally try matching against the C url in record 2
-    recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(column("Name.Url", equalTo("http://C"))));
+    recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(column("Name.Url", equalTo("http://C"))));
 
     readOne(recordReader, "r1 filtered out", r2);
-
   }
 
   @Test
   public void testPaged() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 6);
 
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
     RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(page(4, 4)));
+        columnIO.getRecordReader(memPageStore, recordConverter, FilterCompat.get(page(4, 4)));
 
     List<Group> all = readAll(recordReader);
     assertEquals("expecting records " + all, 4, all.size());
     for (int i = 0; i < all.size(); i++) {
-      assertEquals("expecting record", (i%2 == 0 ? r2 : r1).toString(), all.get(i).toString());
+      assertEquals(
+          "expecting record",
+          (i % 2 == 0 ? r2 : r1).toString(),
+          all.get(i).toString());
     }
   }
 
   @Test
   public void testFilteredAndPaged() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 8);
 
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(and(column("DocId", equalTo(10l)), page(2, 4))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(and(column("DocId", equalTo(10l)), page(2, 4))));
 
     List<Group> all = readAll(recordReader);
     assertEquals("expecting 4 records " + all, 4, all.size());
     for (int i = 0; i < all.size(); i++) {
       assertEquals("expecting record1", r1.toString(), all.get(i).toString());
     }
-
   }
 
   @Test
   public void testFilteredOrPaged() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 8);
 
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(or(column("DocId", equalTo(10l)),
-                column("DocId", equalTo(20l)))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore,
+        recordConverter,
+        FilterCompat.get(or(column("DocId", equalTo(10l)), column("DocId", equalTo(20l)))));
 
     List<Group> all = readAll(recordReader);
     assertEquals("expecting 8 records " + all, 16, all.size());
-    for (int i = 0; i < all.size () / 2; i++) {
+    for (int i = 0; i < all.size() / 2; i++) {
       assertEquals("expecting record1", r1.toString(), all.get(2 * i).toString());
       assertEquals("expecting record2", r2.toString(), all.get(2 * i + 1).toString());
     }
@@ -241,13 +234,12 @@ public class TestFiltered {
 
   @Test
   public void testFilteredNotPaged() {
-    MessageColumnIO columnIO =  new ColumnIOFactory(true).getColumnIO(schema);
+    MessageColumnIO columnIO = new ColumnIOFactory(true).getColumnIO(schema);
     MemPageStore memPageStore = writeTestRecords(columnIO, 8);
 
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
-    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>)
-        columnIO.getRecordReader(memPageStore, recordConverter,
-            FilterCompat.get(not(column("DocId", equalTo(10l)))));
+    RecordReaderImplementation<Group> recordReader = (RecordReaderImplementation<Group>) columnIO.getRecordReader(
+        memPageStore, recordConverter, FilterCompat.get(not(column("DocId", equalTo(10l)))));
 
     List<Group> all = readAll(recordReader);
     assertEquals("expecting 8 records " + all, 8, all.size());
@@ -267,7 +259,7 @@ public class TestFiltered {
 
     RecordConsumer recordWriter = columnIO.getRecordWriter(columns);
     GroupWriter groupWriter = new GroupWriter(recordWriter, schema);
-    for ( int i = 0; i < number; i++ ) {
+    for (int i = 0; i < number; i++) {
       groupWriter.write(r1);
       groupWriter.write(r2);
     }
