@@ -23,8 +23,7 @@ import org.apache.parquet.ParquetRuntimeException;
 public class ParquetEmptyBlockException extends ParquetRuntimeException {
   private static final long serialVersionUID = 1L;
 
-  public ParquetEmptyBlockException() {
-  }
+  public ParquetEmptyBlockException() {}
 
   public ParquetEmptyBlockException(String message, Throwable cause) {
     super(message, cause);
@@ -37,5 +36,4 @@ public class ParquetEmptyBlockException extends ParquetRuntimeException {
   public ParquetEmptyBlockException(Throwable cause) {
     super(cause);
   }
-
 }
