@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -24,7 +24,6 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.HashMap;
 import java.util.Map;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.mapreduce.Counter;
 import org.apache.hadoop.mapreduce.InputSplit;
@@ -37,7 +36,6 @@ import org.apache.hadoop.mapreduce.RecordWriter;
 import org.apache.hadoop.mapreduce.StatusReporter;
 import org.apache.hadoop.mapreduce.TaskAttemptContext;
 import org.apache.hadoop.mapreduce.TaskAttemptID;
-import org.apache.hadoop.mapreduce.TaskInputOutputContext;
 
 /*
  * This is based on ContextFactory.java from hadoop-2.0.x sources.
@@ -85,92 +83,76 @@ public class ContextUtil {
     Class<?> genericCounterCls;
     try {
       if (v21) {
-        jobContextCls =
-            Class.forName(PACKAGE+".task.JobContextImpl");
-        taskContextCls =
-            Class.forName(PACKAGE+".task.TaskAttemptContextImpl");
-        taskIOContextCls =
-            Class.forName(PACKAGE+".task.TaskInputOutputContextImpl");
+        jobContextCls = Class.forName(PACKAGE + ".task.JobContextImpl");
+        taskContextCls = Class.forName(PACKAGE + ".task.TaskAttemptContextImpl");
+        taskIOContextCls = Class.forName(PACKAGE + ".task.TaskInputOutputContextImpl");
         mapContextCls = Class.forName(PACKAGE + ".task.MapContextImpl");
         mapCls = Class.forName(PACKAGE + ".lib.map.WrappedMapper");
-        innerMapContextCls =
-            Class.forName(PACKAGE+".lib.map.WrappedMapper$Context");
-        genericCounterCls = Class.forName(PACKAGE+".counters.GenericCounter");
+        innerMapContextCls = Class.forName(PACKAGE + ".lib.map.WrappedMapper$Context");
+        genericCounterCls = Class.forName(PACKAGE + ".counters.GenericCounter");
       } else {
-        jobContextCls =
-            Class.forName(PACKAGE+".JobContext");
-        taskContextCls =
-            Class.forName(PACKAGE+".TaskAttemptContext");
-        taskIOContextCls =
-            Class.forName(PACKAGE+".TaskInputOutputContext");
+        jobContextCls = Class.forName(PACKAGE + ".JobContext");
+        taskContextCls = Class.forName(PACKAGE + ".TaskAttemptContext");
+        taskIOContextCls = Class.forName(PACKAGE + ".TaskInputOutputContext");
         mapContextCls = Class.forName(PACKAGE + ".MapContext");
         mapCls = Class.forName(PACKAGE + ".Mapper");
-        innerMapContextCls =
-            Class.forName(PACKAGE+".Mapper$Context");
-        genericCounterCls =
-            Class.forName("org.apache.hadoop.mapred.Counters$Counter");
+        innerMapContextCls = Class.forName(PACKAGE + ".Mapper$Context");
+        genericCounterCls = Class.forName("org.apache.hadoop.mapred.Counters$Counter");
       }
     } catch (ClassNotFoundException e) {
       throw new IllegalArgumentException("Can't find class", e);
     }
     try {
-      JOB_CONTEXT_CONSTRUCTOR =
-          jobContextCls.getConstructor(Configuration.class, JobID.class);
+      JOB_CONTEXT_CONSTRUCTOR = jobContextCls.getConstructor(Configuration.class, JobID.class);
       JOB_CONTEXT_CONSTRUCTOR.setAccessible(true);
-      TASK_CONTEXT_CONSTRUCTOR =
-          taskContextCls.getConstructor(Configuration.class,
-              TaskAttemptID.class);
+      TASK_CONTEXT_CONSTRUCTOR = taskContextCls.getConstructor(Configuration.class, TaskAttemptID.class);
       TASK_CONTEXT_CONSTRUCTOR.setAccessible(true);
       GENERIC_COUNTER_CONSTRUCTOR =
-          genericCounterCls.getDeclaredConstructor(String.class,
-              String.class,
-              Long.TYPE);
+          genericCounterCls.getDeclaredConstructor(String.class, String.class, Long.TYPE);
       GENERIC_COUNTER_CONSTRUCTOR.setAccessible(true);
 
       if (useV21) {
-        MAP_CONTEXT_CONSTRUCTOR =
-            innerMapContextCls.getConstructor(mapCls,
-                MapContext.class);
-        MAP_CONTEXT_IMPL_CONSTRUCTOR =
-            mapContextCls.getDeclaredConstructor(Configuration.class,
-                TaskAttemptID.class,
-                RecordReader.class,
-                RecordWriter.class,
-                OutputCommitter.class,
-                StatusReporter.class,
-                InputSplit.class);
+        MAP_CONTEXT_CONSTRUCTOR = innerMapContextCls.getConstructor(mapCls, MapContext.class);
+        MAP_CONTEXT_IMPL_CONSTRUCTOR = mapContextCls.getDeclaredConstructor(
+            Configuration.class,
+            TaskAttemptID.class,
+            RecordReader.class,
+            RecordWriter.class,
+            OutputCommitter.class,
+            StatusReporter.class,
+            InputSplit.class);
         MAP_CONTEXT_IMPL_CONSTRUCTOR.setAccessible(true);
-        WRAPPED_CONTEXT_FIELD =
-            innerMapContextCls.getDeclaredField("mapContext");
+        WRAPPED_CONTEXT_FIELD = innerMapContextCls.getDeclaredField("mapContext");
         WRAPPED_CONTEXT_FIELD.setAccessible(true);
         try {
           Class<?> taskAttemptContextClass = Class.forName(PACKAGE + ".TaskAttemptContext");
-          Method getCounterMethodForTaskAttemptContext
-            = taskAttemptContextClass.getMethod("getCounter", String.class, String.class);
+          Method getCounterMethodForTaskAttemptContext =
+              taskAttemptContextClass.getMethod("getCounter", String.class, String.class);
 
           COUNTER_METHODS_BY_CLASS.put(taskAttemptContextClass, getCounterMethodForTaskAttemptContext);
-
         } catch (ClassNotFoundException e) {
           Class<?> taskInputOutputContextClass = Class.forName(PACKAGE + ".TaskInputOutputContext");
           Method getCounterMethodForTaskInputOutputContextClass =
-            taskInputOutputContextClass.getMethod("getCounter", String.class, String.class);
+              taskInputOutputContextClass.getMethod("getCounter", String.class, String.class);
 
-          COUNTER_METHODS_BY_CLASS.put(taskInputOutputContextClass, getCounterMethodForTaskInputOutputContextClass);
+          COUNTER_METHODS_BY_CLASS.put(
+              taskInputOutputContextClass, getCounterMethodForTaskInputOutputContextClass);
         }
       } else {
-        MAP_CONTEXT_CONSTRUCTOR =
-            innerMapContextCls.getConstructor(mapCls,
-                Configuration.class,
-                TaskAttemptID.class,
-                RecordReader.class,
-                RecordWriter.class,
-                OutputCommitter.class,
-                StatusReporter.class,
-                InputSplit.class);
+        MAP_CONTEXT_CONSTRUCTOR = innerMapContextCls.getConstructor(
+            mapCls,
+            Configuration.class,
+            TaskAttemptID.class,
+            RecordReader.class,
+            RecordWriter.class,
+            OutputCommitter.class,
+            StatusReporter.class,
+            InputSplit.class);
         MAP_CONTEXT_IMPL_CONSTRUCTOR = null;
         WRAPPED_CONTEXT_FIELD = null;
 
-        COUNTER_METHODS_BY_CLASS.put(taskIOContextCls, taskIOContextCls.getMethod("getCounter", String.class, String.class));
+        COUNTER_METHODS_BY_CLASS.put(
+            taskIOContextCls, taskIOContextCls.getMethod("getCounter", String.class, String.class));
       }
       MAP_CONTEXT_CONSTRUCTOR.setAccessible(true);
       READER_FIELD = mapContextCls.getDeclaredField("reader");
@@ -179,10 +161,8 @@ public class ContextUtil {
       WRITER_FIELD.setAccessible(true);
       OUTER_MAP_FIELD = innerMapContextCls.getDeclaredField("this$0");
       OUTER_MAP_FIELD.setAccessible(true);
-      GET_CONFIGURATION_METHOD = Class.forName(PACKAGE+".JobContext")
-          .getMethod("getConfiguration");
-      INCREMENT_COUNTER_METHOD = Class.forName(PACKAGE+".Counter")
-              .getMethod("increment", Long.TYPE);
+      GET_CONFIGURATION_METHOD = Class.forName(PACKAGE + ".JobContext").getMethod("getConfiguration");
+      INCREMENT_COUNTER_METHOD = Class.forName(PACKAGE + ".Counter").getMethod("increment", Long.TYPE);
     } catch (SecurityException e) {
       throw new IllegalArgumentException("Can't run constructor ", e);
     } catch (NoSuchMethodException e) {
@@ -198,16 +178,14 @@ public class ContextUtil {
    * Creates JobContext from a JobConf and jobId using the correct constructor
    * for based on Hadoop version. <code>jobId</code> could be null.
    *
-   * @param conf a configuration
+   * @param conf  a configuration
    * @param jobId a job id
    * @return a job context
    */
   public static JobContext newJobContext(Configuration conf, JobID jobId) {
     try {
-      return (JobContext)
-          JOB_CONTEXT_CONSTRUCTOR.newInstance(conf, jobId);
-    } catch (InstantiationException | IllegalAccessException
-        | InvocationTargetException e) {
+      return (JobContext) JOB_CONTEXT_CONSTRUCTOR.newInstance(conf, jobId);
+    } catch (InstantiationException | IllegalAccessException | InvocationTargetException e) {
       throw new IllegalArgumentException("Can't instantiate JobContext", e);
     }
   }
@@ -216,35 +194,29 @@ public class ContextUtil {
    * Creates TaskAttemptContext from a JobConf and jobId using the correct
    * constructor for based on Hadoop version.
    *
-   * @param conf a configuration
+   * @param conf          a configuration
    * @param taskAttemptId a task attempt id
    * @return a task attempt context
    */
-  public static TaskAttemptContext newTaskAttemptContext(
-      Configuration conf, TaskAttemptID taskAttemptId) {
+  public static TaskAttemptContext newTaskAttemptContext(Configuration conf, TaskAttemptID taskAttemptId) {
     try {
-      return (TaskAttemptContext)
-          TASK_CONTEXT_CONSTRUCTOR.newInstance(conf, taskAttemptId);
-    } catch (InstantiationException | IllegalAccessException
-        | InvocationTargetException e) {
-      throw new IllegalArgumentException("Can't instantiate TaskAttemptContext",
-          e);
+      return (TaskAttemptContext) TASK_CONTEXT_CONSTRUCTOR.newInstance(conf, taskAttemptId);
+    } catch (InstantiationException | IllegalAccessException | InvocationTargetException e) {
+      throw new IllegalArgumentException("Can't instantiate TaskAttemptContext", e);
     }
   }
 
   /**
-   * @param name a string name
+   * @param name        a string name
    * @param displayName a string display name
-   * @param value an initial value
+   * @param value       an initial value
    * @return with Hadoop 2 : <code>new GenericCounter(args)</code>,<br>
-   *         with Hadoop 1 : <code>new Counter(args)</code>
+   * with Hadoop 1 : <code>new Counter(args)</code>
    */
   public static Counter newGenericCounter(String name, String displayName, long value) {
     try {
-      return (Counter)
-          GENERIC_COUNTER_CONSTRUCTOR.newInstance(name, displayName, value);
-    } catch (InstantiationException | IllegalAccessException
-        | InvocationTargetException e) {
+      return (Counter) GENERIC_COUNTER_CONSTRUCTOR.newInstance(name, displayName, value);
+    } catch (InstantiationException | IllegalAccessException | InvocationTargetException e) {
       throw new IllegalArgumentException("Can't instantiate Counter", e);
     }
   }
@@ -266,7 +238,7 @@ public class ContextUtil {
 
   public static Counter getCounter(TaskAttemptContext context, String groupName, String counterName) {
     Method counterMethod = findCounterMethod(context);
-    return (Counter)invoke(counterMethod, context, groupName, counterName);
+    return (Counter) invoke(counterMethod, context, groupName, counterName);
   }
 
   public static boolean hasCounterMethod(TaskAttemptContext context) {
@@ -297,8 +269,8 @@ public class ContextUtil {
    * Invokes a method and rethrows any exception as runtime exceptions.
    *
    * @param method a method
-   * @param obj an object to run method on
-   * @param args an array of arguments to the method
+   * @param obj    an object to run method on
+   * @param args   an array of arguments to the method
    * @return the result of the method call
    */
   private static Object invoke(Method method, Object obj, Object... args) {
