@@ -18,10 +18,10 @@
  */
 package org.apache.parquet.pig;
 
+import static org.apache.parquet.pig.TupleReadSupport.PARQUET_PIG_SCHEMA;
 import static org.apache.pig.builtin.mock.Storage.bag;
 import static org.apache.pig.builtin.mock.Storage.tuple;
 import static org.junit.Assert.assertEquals;
-import static org.apache.parquet.pig.TupleReadSupport.PARQUET_PIG_SCHEMA;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -31,15 +31,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
-
 import org.apache.hadoop.conf.Configuration;
-import org.apache.pig.backend.executionengine.ExecException;
-import org.apache.pig.data.Tuple;
-import org.apache.pig.impl.logicalLayer.schema.Schema;
-import org.apache.pig.impl.util.Utils;
-import org.apache.pig.parser.ParserException;
-import org.junit.Test;
-
+import org.apache.parquet.conf.ParquetConfiguration;
 import org.apache.parquet.example.data.Group;
 import org.apache.parquet.example.data.GroupWriter;
 import org.apache.parquet.example.data.simple.SimpleGroup;
@@ -50,6 +43,12 @@ import org.apache.parquet.io.ConverterConsumer;
 import org.apache.parquet.io.RecordConsumerLoggingWrapper;
 import org.apache.parquet.io.api.RecordMaterializer;
 import org.apache.parquet.schema.MessageType;
+import org.apache.pig.backend.executionengine.ExecException;
+import org.apache.pig.data.Tuple;
+import org.apache.pig.impl.logicalLayer.schema.Schema;
+import org.apache.pig.impl.util.Utils;
+import org.apache.pig.parser.ParserException;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -59,10 +58,8 @@ public class TestTupleRecordConsumer {
   @Test
   public void testArtSchema() throws ExecException, ParserException {
 
-    String pigSchemaString =
-            "DocId:long, " +
-            "Links:(Backward:{(long)}, Forward:{(long)}), " +
-            "Name:{(Language:{(Code:chararray,Country:chararray)}, Url:chararray)}";
+    String pigSchemaString = "DocId:long, " + "Links:(Backward:{(long)}, Forward:{(long)}), "
+        + "Name:{(Language:{(Code:chararray,Country:chararray)}, Url:chararray)}";
 
     SimpleGroup g = new SimpleGroup(getMessageType(pigSchemaString));
     g.add("DocId", 1l);
@@ -90,7 +87,7 @@ public class TestTupleRecordConsumer {
 
   @Test
   public void testMaps() throws ExecException, ParserException {
-        String pigSchemaString = "a: [(b: chararray)]";
+    String pigSchemaString = "a: [(b: chararray)]";
     SimpleGroup g = new SimpleGroup(getMessageType(pigSchemaString));
     Group map = g.addGroup("a");
     map.addGroup("key_value").append("key", "foo").addGroup("value").append("b", "foo");
@@ -103,24 +100,40 @@ public class TestTupleRecordConsumer {
   public void testComplexSchema() throws Exception {
 
     String pigSchemaString = "a:chararray, b:{t:(c:chararray, d:chararray)}";
-    Tuple t0 = tuple("a"+0, bag(tuple("o", "b"), tuple("o1", "b1")));
-    Tuple t1 = tuple("a"+1, bag(tuple("o", "b"), tuple("o", "b"), tuple("o", "b"), tuple("o", "b")));
-    Tuple t2 = tuple("a"+2, bag(tuple("o", "b"), tuple("o", null), tuple(null, "b"), tuple(null, null)));
-    Tuple t3 = tuple("a"+3, null);
+    Tuple t0 = tuple("a" + 0, bag(tuple("o", "b"), tuple("o1", "b1")));
+    Tuple t1 = tuple("a" + 1, bag(tuple("o", "b"), tuple("o", "b"), tuple("o", "b"), tuple("o", "b")));
+    Tuple t2 = tuple("a" + 2, bag(tuple("o", "b"), tuple("o", null), tuple(null, "b"), tuple(null, null)));
+    Tuple t3 = tuple("a" + 3, null);
     testFromTuple(pigSchemaString, Arrays.asList(t0, t1, t2, t3));
-
   }
 
   @Test
   public void testMapSchema() throws Exception {
 
     String pigSchemaString = "a:chararray, b:[(c:chararray, d:chararray)]";
-    Tuple t0 = tuple("a"+0, new HashMap() {{put("foo", tuple("o", "b"));}});
-    Tuple t1 = tuple("a"+1, new HashMap() {{put("foo", tuple("o", "b")); put("foo", tuple("o", "b")); put("foo", tuple("o", "b")); put("foo", tuple("o", "b"));}});
-    Tuple t2 = tuple("a"+2, new HashMap() {{put("foo", tuple("o", "b")); put("foo", tuple("o", null)); put("foo", tuple(null, "b")); put("foo", tuple(null, null));}});
-    Tuple t3 = tuple("a"+3, null);
+    Tuple t0 = tuple("a" + 0, new HashMap() {
+      {
+        put("foo", tuple("o", "b"));
+      }
+    });
+    Tuple t1 = tuple("a" + 1, new HashMap() {
+      {
+        put("foo", tuple("o", "b"));
+        put("foo", tuple("o", "b"));
+        put("foo", tuple("o", "b"));
+        put("foo", tuple("o", "b"));
+      }
+    });
+    Tuple t2 = tuple("a" + 2, new HashMap() {
+      {
+        put("foo", tuple("o", "b"));
+        put("foo", tuple("o", null));
+        put("foo", tuple(null, "b"));
+        put("foo", tuple(null, null));
+      }
+    });
+    Tuple t3 = tuple("a" + 3, null);
     testFromTuple(pigSchemaString, Arrays.asList(t0, t1, t2, t3));
-
   }
 
   private void testFromTuple(String pigSchemaString, List<Tuple> input) throws Exception {
@@ -139,14 +152,15 @@ public class TestTupleRecordConsumer {
       Tuple out = tuples.get(i);
       assertEquals(in.toString(), out.toString());
     }
-
   }
 
   private void testFromGroups(String pigSchemaString, List<Group> input) throws ParserException {
     List<Tuple> tuples = new ArrayList<Tuple>();
     MessageType schema = getMessageType(pigSchemaString);
     RecordMaterializer<Tuple> pigRecordConsumer = newPigRecordConsumer(pigSchemaString);
-    GroupWriter groupWriter = new GroupWriter(new RecordConsumerLoggingWrapper(new ConverterConsumer(pigRecordConsumer.getRootConverter(), schema)), schema);
+    GroupWriter groupWriter = new GroupWriter(
+        new RecordConsumerLoggingWrapper(new ConverterConsumer(pigRecordConsumer.getRootConverter(), schema)),
+        schema);
 
     for (Group group : input) {
       groupWriter.write(group);
@@ -173,12 +187,12 @@ public class TestTupleRecordConsumer {
     }
   }
 
-  private <T> TupleWriteSupport newTupleWriter(String pigSchemaString, RecordMaterializer<T> recordConsumer) throws ParserException {
+  private <T> TupleWriteSupport newTupleWriter(String pigSchemaString, RecordMaterializer<T> recordConsumer)
+      throws ParserException {
     TupleWriteSupport tupleWriter = TupleWriteSupport.fromPigSchema(pigSchemaString);
-    tupleWriter.init(null);
+    tupleWriter.init((ParquetConfiguration) null);
     tupleWriter.prepareForWrite(
-        new ConverterConsumer(recordConsumer.getRootConverter(), tupleWriter.getParquetSchema())
-        );
+        new ConverterConsumer(recordConsumer.getRootConverter(), tupleWriter.getParquetSchema()));
     return tupleWriter;
   }
 
@@ -206,5 +220,4 @@ public class TestTupleRecordConsumer {
     Schema pigSchema = Utils.getSchemaFromString(pigSchemaString);
     return new PigSchemaConverter().convert(pigSchema);
   }
-
 }
